#
# spec file for package soundmodem
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           soundmodem
Version:        0.20
Release:        lp156.2.1
Summary:        Multi-Platform Sound Card Packet Radio Modem
License:        GPL-2.0-only
Group:          Productivity/Hamradio/Packet
URL:            https://gitlab.com/tsailer/soundmodem
Source:         https://web.archive.org/web/20170206060923/http://download.gna.org/soundmodem/%{name}-%{version}.tar.gz
Source1:        soundmodem.conf
Source2:        soundmodem.service
Source3:        soundmodem.sysconfig
Patch0:         fix-ftbfs-i386-multiple-def-mac.patch
BuildRequires:  gcc-c++
BuildRequires:  gtk2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa) >= 1.0.0
BuildRequires:  pkgconfig(audiofile)
BuildRequires:  pkgconfig(libxml-2.0)
Requires(post): %fillup_prereq

%description
Soundmodem allows using sound cards to be used as Packet Radio modems,
in place of a hardware TNC.

Use the soundmodemconfig package and command to generate a configuration file.

%package -n soundmodemconfig
Summary:        GUI configuration and diagnostic utility
Requires:       soundmodem = %{version}
Enhances:       soundmodem

%description -n soundmodemconfig
This package contains the configuration and diagnostic utility for
soundmodem. Use it to generate a configuration file, or test sound card
access and the PTT functionality.

%prep
%autosetup -p1

%build
export CXXFLAGS="%{optflags} -fpermissive"
%configure
%make_build

%install
%make_install
install -d -m 0755 %{buildroot}%{_sysconfdir}/ax25/
install -m 0644 -D %{SOURCE1} %{buildroot}%{_sysconfdir}/ax25/soundmodem.conf
install -m 0644 -D %{SOURCE2} %{buildroot}%{_unitdir}/soundmodem.service
install -m 0644 -D %{SOURCE3} %{buildroot}%{_fillupdir}/sysconfig.soundmodem
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcsoundmodem
rm %{buildroot}%{_includedir}/modem.h
rm %{buildroot}%{_includedir}/simd.h
%find_lang %{name}

%post
%{fillup_only -n soundmodem soundmodem}
%service_add_post soundmodem.service

%postun
%service_del_postun soundmodem.service

%pre
%service_add_pre soundmodem.service

%preun
%service_del_preun soundmodem.service

%files -f %{name}.lang
%license COPYING
%doc ABOUT-NLS AUTHORS ChangeLog NEWS README
%dir %{_sysconfdir}/ax25
%config(noreplace) %{_sysconfdir}/ax25/soundmodem.conf
%{_fillupdir}/sysconfig.soundmodem
%{_sbindir}/soundmodem
%{_sbindir}/rcsoundmodem
%{_unitdir}/soundmodem.service
%{_mandir}/man8/soundmodem.8%{?ext_man}

%files -n soundmodemconfig
%license COPYING
%{_bindir}/soundmodemconfig
%{_mandir}/man8/soundmodemconfig.8%{?ext_man}

%changelog
* Mon Jan 23 2023 Andreas Stieger <andreas.stieger@gmx.de>
- add fix-ftbfs-i386-multiple-def-mac.patch to fix i586 build
* Fri May  1 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.20
- drop fix-extern-inline.patch, not needed
- Fix packaging:
  * configuration file was a directory
  * systemd unit packaged as a directory
  * systemd was not working and referenced non-existing config file
  * make systemd unit configurable and log to journal by default
  * split soundmodemconfig package to avoid pulling in GUI packages
    when running the modem only
* Fri Feb 22 2019 Martin Hauke <mardnh@gmx.de>
- Run spec-cleaner
- Use pkgconfig-style dependencies
- Workaround some compiler warnings to fix build on Tumbleweed
  Add "-fpermissive" to CXXFLAGS
* Mon Nov  2 2015 rpm@fthiessen.de
- Updated to version 0.18
  * Added fix-extern-inline.patch from Arch linux
- Added service file and removed init file
* Wed Feb 20 2013 dl8fcl@darc.de
- fixed for 12.2 and newer
* Mon Oct 31 2011 dl8fcl@darc.de
- Update to version 0.16
* Tue Oct 21 2008 dl9pf@gmx.de
- fix for factory
- import debian's diff
- soundmodem-0.10_pammodem_meas.c__fix_include.diff
* Sun Oct  5 2008 dl9pf@gmx.de
- factory_64bit_check_fix.diff
* Mon May 17 2004 jreuter@suse.de
- upgrade to version 0.7
- fix missing includes in interface.c (spectrum.h, scope.h)
* Sat Jan 10 2004 adrian@suse.de
- fix build as user
* Fri Nov  7 2003 ro@suse.de
- fix configure.in for current autoconf
* Wed Aug 20 2003 sbrabec@suse.cz
- Removed obsolete libgtop from neededforbuild.
* Fri Aug 15 2003 adrian@suse.de
- add desktop file
* Tue Jul 29 2003 aj@suse.de
- Fix chown invocation.
* Fri Jun 20 2003 ro@suse.de
- build with current gettext
* Wed Jun 18 2003 ro@suse.de
- remove unpackaged files from buildroot
* Thu Nov 21 2002 ro@suse.de
- add AM_GNU_GETTEXT_VERSION
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Wed Sep 18 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Fri Jun 14 2002 ro@suse.de
- always use macros when calling insserv
* Tue Apr 16 2002 ro@suse.de
- remove START_ variable
- update to 0.6, bzipped source
* Fri Feb  1 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Jan 15 2002 egmont@suselinux.hu
- removed colons from startup/shutdown messages
* Mon Sep 24 2001 jreuter@suse.de
- fixed rc script for LSB compliance (closes bug #9099)
* Sat Dec  2 2000 ka@suse.de
- update tp version 0.4
- added INIT INFO to init script
- added insserv call to spec file for symbolic links to init script
* Sat Dec  2 2000 ka@suse.de
- renamed to soundmodem
* Fri Dec  1 2000 uli@suse.de
- moved init script to /etc/init.d
* Thu Nov 30 2000 jreuter@suse.de
- changed group to Utilities/Hamradio
* Mon Nov  6 2000 ro@suse.de
- fixed neededforbuild
* Wed Sep 20 2000 ka@suse.de
- initial release 0.2
